library abribbon;

import 'package:abribbon/abribbon.dart';
import 'package:flutter/material.dart';

import 'abribbon_tabs.dart';

class ABRibbon extends StatefulWidget {
  ABRibbon({
    Key? key,
    this.tabHeight = 62.0,
    this.itemBarHeight = 100.0,
    this.width = double.infinity,
    this.elevation = 1.0,
    required this.primaryColor,
    required this.secondaryColor,
    required this.ribbonTabs,
    required this.tabsCount,
    required this.ribbonTabItems,
  })   : assert(ribbonTabItems.length == tabsCount),
        super(key: key);

  final double tabHeight;
  final double itemBarHeight;
  final double width;
  final double elevation;
  final Color primaryColor;
  final Color secondaryColor;

  final int tabsCount;
  final List<ABRibbonTabs> ribbonTabs;
  final List<ABRibbonTabItem> ribbonTabItems;

  @override
  _ABRibbonState createState() => _ABRibbonState();
}

class _ABRibbonState extends State<ABRibbon> with TickerProviderStateMixin {
  late TabController _tabController;

  double get _width => widget.width;
  double get _tabHeight => widget.tabHeight;
  double get _itemBarHeight => widget.itemBarHeight;
  double get _elevation => widget.elevation;
  Color get _primaryColor => widget.primaryColor;
  Color get _secondaryColor => widget.secondaryColor;

  int get _tabsCount => widget.tabsCount;
  List<ABRibbonTabs> get _ribbonTabs => widget.ribbonTabs;
  List<ABRibbonTabItem> get _ribbonTabItem => widget.ribbonTabItems;

  @override
  void initState() {
    super.initState();
    _tabController = TabController(length: _tabsCount, vsync: this);
  }

  @override
  void dispose() {
    _tabController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        Container(
          height: _tabHeight,
          width: _width,
          decoration: BoxDecoration(
            color: _primaryColor,
          ),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.end,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding: const EdgeInsets.only(left: 16.0),
                child: TabBar(
                  controller: _tabController,
                  isScrollable: true,
                  physics: NeverScrollableScrollPhysics(),
                  unselectedLabelColor: _secondaryColor,
                  labelColor: _primaryColor,
                  indicator: BoxDecoration(color: _secondaryColor),
                  tabs: _buildTabsFromList(),
                ),
              ),
            ],
          ),
        ),
        Material(
          elevation: _elevation,
          child: Container(
            height: _itemBarHeight,
            width: double.infinity,
            decoration: BoxDecoration(
              color: _secondaryColor,
            ),
            child: TabBarView(
              controller: _tabController,
              physics: NeverScrollableScrollPhysics(),
              children: _buildTabsItemFromList(),
            ),
          ),
        ),
      ],
    );
  }

  List<Widget> _buildTabsFromList() {
    List<Widget> widgets = [];
    for (int i = 0; i < _tabsCount; i++) {
      widgets.add(_ribbonTabs[i]);
    }
    return widgets;
  }

  List<Widget> _buildTabsItemFromList() {
    List<Widget> widgets = [];
    for (int i = 0; i < _ribbonTabItem.length; i++) {
      widgets.add(_ribbonTabItem[i]);
    }
    return widgets;
  }
}
